@@ -51,6 +51,7 @@ from alfasim_sdk._internal.alfacase.case_description import (
     EnvironmentPropertyDescription,
 )
 from alfasim_sdk._internal.alfacase.case_description import EquipmentDescription
+from alfasim_sdk._internal.alfacase.case_description import AnnulusEquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import FluidDescription
 from alfasim_sdk._internal.alfacase.case_description import FormationDescription
 from alfasim_sdk._internal.alfacase.case_description import FormationLayerDescription
@@ -231,6 +232,7 @@ from alfasim_sdk._internal.constants import HydrodynamicModelType
 from alfasim_sdk._internal.constants import InitialConditionStrategyType
 from alfasim_sdk._internal.constants import InterpolationType
 from alfasim_sdk._internal.constants import LeakLocation
+from alfasim_sdk._internal.constants import EquipmentAttachmentLocation
 from alfasim_sdk._internal.constants import LeakModel
 from alfasim_sdk._internal.constants import LeakType
 from alfasim_sdk._internal.constants import MassInflowSplitType
@@ -335,6 +337,7 @@ __all__ = [
     "EnvironmentDescription",
     "EnvironmentPropertyDescription",
     "EquipmentDescription",
+    "AnnulusEquipmentDescription",
     "FluidDescription",
     "FormationDescription",
     "FormationLayerDescription",
@@ -353,6 +356,7 @@ __all__ = [
     "LengthAndElevationDescription",
     "LeakEquipmentDescription",
     "LeakLocation",
+    "EquipmentAttachmentLocation",
     "LightComponentDescription",
     "LinearIPRDescription",
     "MassSourceEquipmentDescription",
@@ -439,7 +443,6 @@ __all__ = [
     "HydrodynamicModelType",
     "InitialConditionStrategyType",
     "InterpolationType",
-    "LeakLocation",
     "LeakModel",
     "LeakType",
     "MassInflowSplitType",
