@@ -44,8 +44,12 @@ CATEGORIES_USED_ON_DESCRIPTION = sorted(
         "dynamic viscosity",
         "emissivity",
         "flow coefficient",
+        "force",
+        "force per velocity",
+        "force per velocity squared",
         "heat transfer coefficient",
         "length",
+        "mass",
         "mass flow rate",
         "mass fraction",
         "mass per mol",
@@ -171,7 +175,7 @@ def _get_declaration(
 
                     # For Schema: if the attributes have a default value the entry is optional.
                     if default_value and is_schema:
-                        if attribute_value.startswith("\n"):
+                        if attribute_value.lstrip(" \t").startswith("\n"):
                             attribute_value = " # optional" + attribute_value
                         else:
                             attribute_value += "  # optional"
